(function () {
	var EXIT_URL = "./exit.html"


	var app = null
	var exitWindow = null
	var focusWindow = null
	var webDogTimer = null
	var lastFeedDogTime = 0

	if (!webapis) {
		return
	}

	function webLog(str) {
		window.webLog && window.webLog("main:" + str)
	}

	function checkNetwork(url, success, error) {
		var xhr = new XMLHttpRequest()
		xhr.open("GET", url, true)

		xhr.onload = function () {
			success && success()
		}
		xhr.onerror = function (e) {
			error && error(e)
		}
		xhr.send()
	}


	function init() {
		try {
			var ua = window.navigator.userAgent
			if (ua.indexOf("zlzp/") === -1) {
				ua += " zlzp/" + APP_VER
			}
			tizen.websetting.setUserAgentString(ua, function () {
				webLog("setUserAgentString ok")
			}, function () {
				webLog("setUserAgentString ok")
			})
			webLog("init")
			registerKey()
			feedWebDog()
			startWebDog()
			window.onkeydown = handleKeydown

			checkNetwork(APP_URL, function () {
				showTips("")
				app = new TizenWebView()
				app.loadUrl(APP_URL + "/ott/main")
				injectApi(app)
				app.onload = function () {
					injectApi(app)
					app.focus()
					hideStarBg()
				}
				app.onerror = function () {
					restartApp(5000)
				}
			}, function () {
				webLog("navigator offline")
				restartApp(15000, '网络错误,5秒后重试')
				return
			})

		} catch (error) {
			webLog("init error:" + error.message)
		}
	}
	
	function hideStarBg(){
//		document.body.className=""
	}

	function injectApi(app) {
		app.injectApi("feedWebDog", feedWebDog)
		app.injectApi("webLog", function (str) {
			window.webLog && window.webLog("web>" + str)
		})
		app.injectApi("onkeydown", handleKeydown)
		if (window.TizenApiObject) {
			window.TizenApiObject.restartApp = restartApp
			app.injectApi("TizenApi", window.TizenApiObject)
		}
	}

	function restartApp(time, tips) {
		time = time || 15
		setTimeout(function () {
			window.location.reload()
		}, time)
		webLog("restartApp" + time)
		tips = tips || "应用将在" + Math.floor(time / 1000) + "秒后重启"
		showTips(tips)
	}

	function showTips(tips) {
		var dom = document.getElementById("app_tips")
		if (!dom) {
			return
		}
		if (tips) {
			dom.innerHTML = "<div class='error-tips'>" + tips + "</div>"
			dom.style.display = "block"
			return
		}
		dom.style.display = "none"

	}

	function feedWebDog() {
		lastFeedDogTime = Date.now()
		webLog("feedWebDog:" + lastFeedDogTime)
	}

	function startWebDog() {
		var diff = Date.now() - lastFeedDogTime
		webLog("startWebDog diff:" + diff)
		if (diff > 5 * 60 * 1000) {
			window.location.reload()
			feedWebDog()
		}
		clearTimeout(webDogTimer)
		webDogTimer = setTimeout(function () {
			startWebDog()
		}, 30*1000)
	}

	function registerKey() {
		try {
			var i, keyCode = {}, supportedKeys
			supportedKeys = tizen.tvinputdevice.getSupportedKeys()
			for (i = 0; i < supportedKeys.length; i++) {
				keyCode[supportedKeys[i].name] = supportedKeys[i].code
			}
			if (keyCode.hasOwnProperty("Exit")) {
				tizen.tvinputdevice.registerKey("Exit")
				webLog("registerKey Exit success")
			}
		} catch (error) {
			webLog("registerKey" + error.message)
		}
	}

	function handleKeydown(event) {
		webLog("keydown:" + event.keyCode)
		var keyName = getKeyNameByEvent(event)
		if (keyName === "EXIT" || keyName === "BACK") {
			focusWindow = event.view
			showExitWindow()
		}
	}


	function showExitWindow() {
		webLog("showExitWindow")
		if (exitWindow) {
			exitWindow.dispose()
		}

		exitWindow = new TizenWebView()
		exitWindow.loadUrl(EXIT_URL)

		exitWindow.injectApi("webLog", window.webLog)
		exitWindow.injectApi("getKeyNameByEvent", getKeyNameByEvent)
		exitWindow.injectApi("restartApp", restartApp)
		exitWindow.injectApi("closeWindow", function () {
			webLog("closeWindow")
			exitWindow.dispose()
			exitWindow = null
			if (focusWindow && focusWindow !== app.dom.contentWindow) {
				focusWindow.focus()
			} else {
				app.focus()
			}
		})
		exitWindow.injectApi("logoutApp", function () {
			webLog("logoutApp")
			var localStorage = app.dom.contentWindow.localStorage
			localStorage && localStorage.removeItem('token')
			localStorage && localStorage.removeItem('pass')
			restartApp()
		})
		exitWindow.injectApi("exitApp", function () {
			webLog("exitApp")
			tizen.application.getCurrentApplication().exit()
		})
		exitWindow.onload = function () {
			exitWindow.focus()
		}
	}
	window.__init = init
	window.init = window.superInit || init
})()